package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````;!@``#0```!\D0````(`!30`(``)
M`"@`&P`:``$``'`8AP``&(<``!B'```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$````````````````````DAP``)(<```4```````$`
M`0```*"-``"@C0$`H(T!`*`"``"X$@``!@```````0`"````J(T``*B-`0"H
MC0$`$`$``!`!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DH(T`
M`*"-`0"@C0$`8`(``&`"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5`(^DJ77A=&J;AXAC%(W2R==7R1,Y!````!`````!
M````1TY5```````#`````@`````````1````3P````@````(`````9`0!"5`
M!(`H@``%H(90A(`!```+*`2,.*`218H```A/````4````%,```!7````6```
M`&````!A````8@```&0```!E````9P```&@```!I````:@```&T`````````
M``````&O-.ANQ=\?SMY'+6M_FGPNQ9NV=E0\E"#_Y`[59-1\V7%8'.)'Q@%"
M^M>'K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>OS&9"1=7LB0=PTPT4
MXI[:S>.>,V+;[16,)<P-.I<+?ZF<F[[:5QO@IP(*:QJ>4*/@^TD`````````
M`````````````````)02`````````P`+````````D`$```````,`%@"0`@``
M```````````2````,0,`````````````$@````4#`````````````"(```!*
M`P`````````````1````QP,`````````````$@```!$``````````````"``
M``#;`0`````````````2````Y`(`````````````$@```"(#````````````
M`!(````1`0`````````````2````=`,`````````````$0```+0`````````
M`````!(```"K`@`````````````2````@P$`````````````$@```)<"````
M`````````!(```"$```````````````2````#`$`````````````$@```+("
M`````````````!(```!T`@`````````````2````.@(`````````````$@``
M`%0#`````````````!(```!+`@`````````````2````6`(`````````````
M$@````$!`````````````!$```!G`0`````````````2````XP``````````
M````$0```#4!`````````````!(```#K`@`````````````2````W0(`````
M````````$0```,(``````````````!(```"Q`0`````````````2````$@(`
M````````````$@```)X!`````````````!(```#+`@`````````````2````
M]P$`````````````$@```*H!`````````````!(````X`P`````````````2
M````0P$`````````````$@```"T``````````````"````!M`@``````````
M```2````)`(`````````````$@```(("`````````````!(```"\`0``````
M```````1````9```````````````$@```/0"`````````````!(```"3````
M```````````2````X`$`````````````$@```!0#`````````````!(```"?
M```````````````2````7`$`````````````$@```%("`````````````!(`
M``")`@`````````````2````(@$`````````````$@```%8`````````````
M`!(````6`0`````````````2````DP$`````````````$@```)T"````````
M`````!(```#P```````````````2````9@(`````````````$@```"H#````
M`````````!(```![`@`````````````2````=0$`````````````$@```',`
M`````````````!(```!+`P`````````````A````^P(`````````````$@``
M`-0``````````````!(```!3`0`````````````2````/```````````````
M(````$P#`````````````!$```#3`@`````````````2````*0(`````````
M````$@```&`"`````````````!(```#Q`0`````````````2````P`(`````
M````````$@```#$"`````````````!(```#^`0`````````````2````Y`,`
M`%B@`0``````$``7`-`#```T-P``?````!(`#0`(!```%"L``,P'```2``T`
M10,``*@5``#$`@``$@`-`)8#``#T(@``!````!(`#0"G`P``0)`!```````0
M`!<`I`0``/@B``"P`@``$@`-`-H$``#@,@``5`0``!(`#0"0!```0)`!````
M```0`!<`[P,``*@E```H````$@`-`!4$``!(1@``'`$``!(`#0`M!```0$D`
M``0````1``\`;`0``%B@`0``````$``7`'$$``!8H`$``````!``%P"<!```
M."$``%`````2``T`L00```0J```0`0``$@`-`,,$```T*0``N````!(`#0`@
M!````)`!```````0`!8`_`,``-`E```D`0``$@`-`-P#``!`D`$``````!``
M%@!B!```/)`!``0````1`!8`A@,``"!)```$````$@`-`%($``#`2```8```
M`!(`#0`F!```;!@````````2``T`T00``+Q%``",````$@`-`"($````D`$`
M`````"``%@"U`P``["D``!@````2``T`XP,``%B@`0``````$``7`#P$``#X
M(0``_````!(`#0"&!```9$<``%P!```2``T`>00``/0F``!``@``$@`-``!L
M:6)P97)L+G-O+C4N,S``7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?
M9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S
M>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?
M8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E
M<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`
M4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L
M7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?
M<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R
M;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L
M7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R
M>5]W<F%P`&QI8G!T:')E860N<V\N,`!R96%D`%]?97)R;F]?;&]C871I;VX`
M8VQO<V4`;W!E;C8T`'!T:')E861?9V5T<W!E8VEF:6,`;'-E96LV-`!L:6)C
M+G-O+C8`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`
M=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M8VAR`&=E='!I9`!S=')D
M=7``<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`%]?9G!R:6YT
M9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER
M`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H<@!R96%D
M9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C
M8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G
M:7-T97)?871F;W)K`&QD+6QI;G5X+G-O+C,`7U]S=&%C:U]C:&M?9W5A<F0`
M7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`7U]B<W-?<W1A<G1?
M7P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?961A
M=&$`7U]B<W-?96YD7U\`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M
M:W1M<&1I<@!S:&%?=7!D871E`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E
M9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A
M<E]P;`!?96YD`%]?96YD7U\`<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S
M<U]S=&%R=`!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T
M:`!P87)?96YV7V-L96%N`'-H85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/
M5`!'3$E"0U\R+C0``````````@`"``(``@`"`````P`"``(``@`$`````@``
M``(```````(``@`"``(``@`"`````````````@`"```````#`````@`#``(`
M`@```````@`"``(```````(````#``(```````(``@````````````(````"
M``(``@```````@`"``````````(``@`"``(``P`"``(``P`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!`````0`!`&8#```0````(````!1I:0T```0`\`0````````!``$`
MRP$``!`````@````%&EI#0```P#P!`````````$``0`:`@``$``````````4
M:6D-```"`/`$````````H(T!`!<```"DC0$`%P```,"/`0`7````Z(\!`!<`
M``#PCP$`%P````20`0`7````#)`!`!<````0D`$`%P```!B0`0`7````')`!
M`!<````@D`$`%P```"20`0`7````*)`!`!<````PD`$`%P```#20`0`7````
M/)`!`!<```#$CP$`%04``,B/`0`5"```S(\!`!4-``#0CP$`%1```-2/`0`5
M&@``V(\!`!4<``#<CP$`%1\``."/`0`5*0``Y(\!`!4M``#LCP$`%3<``/2/
M`0`500``^(\!`!5&``#\CP$`%4<``,2.`0`6`P``R(X!`!8$``#,C@$`%@4`
M`-".`0`6!P``U(X!`!8)``#8C@$`%@H``-R.`0`6"P``X(X!`!8,``#DC@$`
M%@X``.B.`0`6#P``[(X!`!81``#PC@$`%A(``/2.`0`6$P``^(X!`!84``#\
MC@$`%A4```"/`0`6%@``!(\!`!87```(CP$`%A@```R/`0`6&0``$(\!`!8;
M```4CP$`%AT``!B/`0`6'@``'(\!`!8@```@CP$`%B$``"2/`0`6(@``*(\!
M`!8C```LCP$`%B0``#"/`0`6)0``-(\!`!8F```XCP$`%B<``#R/`0`6*```
M0(\!`!8I``!$CP$`%BH``$B/`0`6*P``3(\!`!8L``!0CP$`%BX``%2/`0`6
M+P``6(\!`!8P``!<CP$`%C$``&"/`0`6,@``9(\!`!8S``!HCP$`%C0``&R/
M`0`6-0``<(\!`!8V``!TCP$`%C@``'B/`0`6.0``?(\!`!8Z``"`CP$`%CL`
M`(2/`0`6/```B(\!`!8]``",CP$`%CX``)"/`0`6/P``E(\!`!9```"8CP$`
M%D,``)R/`0`61```H(\!`!9%``"DCP$`%D@``*B/`0`620``K(\!`!9*``"P
MCP$`%DL``+2/`0`63```N(\!`!9-``"\CP$`%DX```A`+>F)`0#K"("]Z`3@
M+>4$X)_E#N"/X`CPON4(?`$``,:/XA?*C.((_+SE`,:/XA?*C.(`_+SE`,:/
MXA?*C.+X^[SE`,:/XA?*C.+P^[SE`,:/XA?*C.+H^[SE`,:/XA?*C.+@^[SE
M`,:/XA?*C.+8^[SE`,:/XA?*C.+0^[SE`,:/XA?*C.+(^[SE`,:/XA?*C.+`
M^[SE`,:/XA?*C.*X^[SE`,:/XA?*C.*P^[SE`,:/XA?*C.*H^[SE`,:/XA?*
MC.*@^[SE`,:/XA?*C.*8^[SE`,:/XA?*C.*0^[SE`,:/XA?*C.*(^[SE`,:/
MXA?*C.*`^[SE`,:/XA?*C.)X^[SE`,:/XA?*C.)P^[SE`,:/XA?*C.)H^[SE
M`,:/XA?*C.)@^[SE`,:/XA?*C.)8^[SE`,:/XA?*C.)0^[SE`,:/XA?*C.)(
M^[SE`,:/XA?*C.)`^[SE`,:/XA?*C.(X^[SE`,:/XA?*C.(P^[SE`,:/XA?*
MC.(H^[SE`,:/XA?*C.(@^[SE`,:/XA?*C.(8^[SE`,:/XA?*C.(0^[SE`,:/
MXA?*C.((^[SE`,:/XA?*C.(`^[SE`,:/XA?*C.+X^KSE`,:/XA?*C.+P^KSE
M`,:/XA?*C.+H^KSE`,:/XA?*C.+@^KSE`,:/XA?*C.+8^KSE`,:/XA?*C.+0
M^KSE`,:/XA?*C.+(^KSE`,:/XA?*C.+`^KSE`,:/XA?*C.*X^KSE`,:/XA?*
MC.*P^KSE`,:/XA?*C.*H^KSE`,:/XA?*C.*@^KSE`,:/XA?*C.*8^KSE`,:/
MXA?*C.*0^KSE`,:/XA?*C.*(^KSE`,:/XA?*C.*`^KSE`,:/XA?*C.)X^KSE
M`,:/XA?*C.)P^KSE`,:/XA?*C.)H^KSE`,:/XA?*C.)@^KSE`,:/XA?*C.)8
M^KSE`,:/XA?*C.)0^KSE`,:/XA?*C.)(^KSE`,:/XA?*C.)`^KSE`,:/XA?*
MC.(X^KSE`,:/XA?*C.(P^KSE`,:/XA?*C.(H^KSE`,:/XA?*C.(@^KSE`,:/
MXA?*C.(8^KSE:,*?Y6@RG^5P0"WI#,"/X"#03>(4`(WE$!"-Y0P@C>4#,)SG
M$!"-X@P@C>(4`(WB0$*?Y0`PD^4<,(WE`#"@XYK__^LP(I_E!$"/X"PRG^4"
M()3G`P"4YP(0H.'&#`#K'#*?Y0,PE.<`8-/E``!6XU@```H,,I_E`U"4YP``
ME>7;___KQB/0Y0`PH.$"((+CQB/#Y0``E>75___K%#"=Y04P@^('`7/CQB/0
MY0$@@N/&(\#E90``B@,!H.%=___K$!"=Y<#AG^44()WEO,&?Y0[@C^`,P(_@
M`0!2XP#@GN4`,*#A``"1Y0``@^6@`9_E"."#Y0``C^`$`(/EE`&?Y03@H.,`
M`(_@#`"#Y0P`H.$$`$'""#",Y03@C.4"`8#`#,"#P@,``-H$X+'E!."LY0$`
M4.'[__\:7%&?Y0`0H.,-P8+B!5"/X!``E>4`$(WE#!&#YT01G^4#((+B`1"/
MX'/__^L`0%#B)P``"C!1G^488(WB!5"/X!``E>4;___K(`&?Y080H.$``(_@
MJP``ZP``4.,@```*##&?Y0,PC^`0`)/E_/[_ZUO__^O\()_EO#"?Y0(@C^`#
M,)+G`""3Y1PPG>4"(#/@)P``&@0`H.$@T(WB<("]Z!#__^O0()_E`B"/X```
M4.,0`(+E'```"N;^_^N,,)_E`U"4YP``E>5[___K<6?`Y9O__^H0`)7E8O__
MZP!`H.'3___J#`"5Y0``4.,!```*UP<`Z]G__^J``)_E!A"@X0``C^!_``#K
M``!0XPP`A>72__\*]?__ZF0PG^5D`)_E`Q"4YP``C^`A___K`0"@XPK__^O3
M_O_K_'@!`!0!``#`>`$`-`$``#P!```@`0``'`$``+QY`0#`>0$`U#4``,@U
M``!0>0$`?`H``"!Y`0`(,P``^'@!`%1W`0"T>`$`]#$``"P!``"H,P```+"@
MXP#@H.,$$)WD#2"@X00@+>4$`"WE**"?Y20PC^(#H(K@(,"?Y0S`FN<$P"WE
M&#"?Y0,PFN<4`)_E``":Y]?^_^LM___K!'8!``@!```P`0``.`$``!0PG^44
M()_E`S"/X`(@D^<``%+C'O\O`='^_^KD=0$`*`$``"P`G^4L,)_E``"/X`,P
MC^```%/A(#"?Y0,PC^`>_R\!&""?Y0(PD^<``%/C'O\O`1/_+^%(=P$`1'<!
M`+!U`0`0`0``.`"?Y3@0G^4``(_@`1"/X``00>"A/Z#A01&#X"0PG^7!$+#A
M`S"/X![_+P$8()_E`C"3YP``4^,>_R\!$_\OX01W`0``=P$`8'4!`$`!``!,
M,)_E3""?Y0,PC^``,-/E`B"/X```4^,>_R\1.#"?Y1!`+>D#,)+G``!3XP(`
M``HH,)_E`P"?YT3^_^O*___K'#"?Y0$@H.,#,(_@`"##Y1"`O>BT=@$`)'4!
M``P!``!,=@$`='8!`-#__^K0,)_E\$<MZ0"04.(#,(_@+```"L`@G^4",)/G
M`("3Y0``6.,I```*`"#9Y0%PH.$]4%+B`5"@$P``4N,`4*`#``!5XQ$``!H`
M0)CE``!4XPP```H(8*#A!2"@X0D0H.$$`*#AP_[_ZP``4.,"```:!3#4YST`
M4^,+```*!$"VY0``5./S__\:!`"@X?"'O>@)4*#A`3#UY0``4^,]`%,3^___
M&@E01>#F___J"&!&X`%0A>)&8:#A!4"$X`0`H.$`8(?E\(>]Z`E`H.'M___J
M"$"@X>O__^J\=`$`1`$``*@@G^6H,)_E`B"/X'!`+>D#,)+GG%"?Y0C03>(`
M0*#A`#"3Y00PC>4`,*#C!5"/X`U@H.$&$*#A!`"@X;?__^L``%#C#@``"FPP
MG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#
MY```4N/[__\:Z___ZC0@G^4D,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^`!```:
M"-"-XG"`O>C[_?_KX',!`!0!``"\<P$`1`$``%QS`0#P3RWI`##1Y1PBG^4]
M`%/C&#*?Y0(@C^`!0*#A`S"2YP%`@0(,T$WB`%"@X00`H.$`,)/E!#"-Y0`P
MH.,?_O_K#1"@X>B!G^4(@(_@`&"@X04`H.&`___K`)!0XD(```H6_O_K!@!0
MX3D``"K$,9_E`'"=Y0.`F.<'<:#A``#5Y3T@4.(!(*`3``!0XP`@H`,``%+C
M!0``"@4@H.$!,/+E``!3XST`4Q/[__\:!2!"X`(`AN("`(#@`&"8Y>W]_^L`
M`%#C!P"&YU$```H`()CE`!"=Y04`H.$!,-#D`1&2YST`4^,``%,3`##!Y08`
M``H!(('B`3#0Y`(0H.$``%/C/0!3$P$PPN3Y__\:/3"@XP$@H.$`,,'E`3#4
MY`$PXN4``%/C^___&@``H.,((9_E^#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@
M-@``&@S0C>+PC[WH`9!)X@$PU.0!,.GE``!3X_O__QKN___JQ#"?Y0.`F.<`
MH)CE`#":Y0``4^,E```*"C"@X00@L^4)$*#A``!2XP&0B>+Z__\:`Q"!X@$1
MH.&4,)_E`S"/X``@D^4``%+C#P``&@$@H.,!`*#A`""#Y:O]_^L`L%#B$```
M"@EQH.$*$*#A!R"@X6/]_^L`L(CE`3")X@`@H.,#(8OG`)"-Y:#__^H*`*#A
M?_W_ZP``4.,`L*#A"7&@$0``B.7S__\:``#@X\/__^H#D*#A"!"@X][__^IK
M_?_K$',!`!0!``#<<@$`1`$``/!Q`0`(<P$`;"&?Y6PQG^4"((_@\$$MZ0,P
MDN=XT$WB`$!0X@`PD^5T,(WE`#"@XP(```H`,-3E``!3XPD``!H\(9_E-#&?
MY0(@C^`#,)+G`""3Y70PG>4"(#/@10``&GC0C>+P@;WH;?W_ZP!04.+R__\*
M#'&?Y0=PC^`%`*#AN/W_ZP``4.,F```*$S#0Y1.`@.(N`%/C)P``"A,PT.4N
M`%/C*@``"@0`H.%T_?_K`&"@X0@`H.%Q_?_K``"&X`(`@.)<_?_K!S"@X0`@
MX.,!$*#C$`&-Z`!@H.%W_?_K!A"@X0@@C>(#`*#CIOW_ZP$`<.,&`*#A`P``
M"A@PG>4/.@/B`0E3XQ@```HI_?_K!@"@X0G]_^L%`*#AD?W_ZP``4./8__\:
M!0"@X:7]_^L$`*#A"OW_Z\#__^H!,-CE``!3X\S__PH3,-#E+@!3X]3__QH!
M,-CE+@!3X]'__QH",-CE``!3X\/__PK-___JI/__Z^7__^H(_?_KV'`!`!0!
M``"@<`$`."L``)3`G^64,)_E#,"/X!!`+>EPT$WB`S"<YP`0H.$`0*#A#2"@
MX0,`H.,`,)/E;#"-Y0`PH.-]_?_K``!0XP``H!,$```:$#"=Y0\Z`^(*"E/C
M`0E3$PD```I$()_E/#"?Y0(@C^`#,)+G`""3Y6PPG>4"(#/@!P``&G#0C>(0
M@+WH!`"@X0(0H.-*_?_K$`]OX:`"H.'O___JW?S_ZU1O`0`4`0``_&X!`/!!
M+>D4X9_E`=I-XA#!G^4(T$WB#N"/X`!`H.$$`9_E#,">YP$ZC>($<(WB^""?
MY0%@H.$``(_@!Q"@X00P@^(`P)SE`,"#Y0#`H./8_/_KV#"?Y0,PC^``P%#B
M)0``V@A0C>(!@$SB"%"%X,`@G^4$$%7E`C"3YP``4>,`4)/E&@``&@``6.,=
M```*"""@X2\0H.,'`*#A&?W_ZP``4.,7```*!0"@X3S]_^L(,*#A!R"@X000
MH.$@_?_K=!"?Y5P@G^4!$(_@`3J-X@(@D><$,(/B`!"2Y0`@D^4!$#+@#0``
M&@':C>((T(WB\(&]Z`R`H.'D___J-""?Y0(PD^<`4)/E!0"@X23]_^L&(*#A
M!!"@X:/\_^OG___JDOS_ZZ!N`0`4`0``4"D``/\/``!@;@$`'`$``/!M`0`0
M0"WI,$"?Y3`PG^4$0(_@`S"4YP``D^41_?_K(""?Y2`PG^4@$)_E`B"4YP,P
MC^`00+WH`1"/X,K\_^IL;0$`'`$``!@!``!\90``)"@``%0PG^54()_E`S"/
MX!!`+>D"0)/G"-!-X@``E.7\_/_KXO__ZP``E.7Y_/_K`""@XRPPG^4$((WE
M*!"?Y2@@G^4#,(_@`B"/X`$0C^``,(WEQ?S_ZPC0C>(0@+WH(&T!`!P!``"D
M*@``W"<```P1``#<$)_E<$`MZ=@@G^4"VDWB&-!-X@$0C^`"()'G`CJ-XA0P
M@^(`()+E`""#Y0`@H..!_/_KL#"?Y0Q`C>(#,(_@!#"-Y:0PG^4!:HWBH""?
MY0,PC^`!$*#C$&"&X@``C>4$`*#AB?S_ZP0`H.$&$*#A`2J@XT_\_^L`0%#B
M`%"@LP@``+H!`(3B7_S_ZP!04.($```*!A"@X00@H.$A_/_K`#"@XP0PQ>=(
M$)_E-""?Y0$0C^`".HWB`B"1YQ0P@^(`$)+E`""3Y0$0,N`#```:!0"@X0+:
MC>(8T(WB<("]Z"+\_^ND;`$`%`$``)PG``!\)P```1````AL`0"____J=,*?
MY?!/+>EP(I_E0MU-X@S03>(,P(_@`%"@X6`"G^4"()SG0CV-XAA@C>(!@*#A
M``"/X`80H.$$,(/B`""2Y0`@@^4`(*#CJ/W_ZR\0H.,`0*#A!0"@X4/\_^L`
M`%#C$0``"AP"G^4%$*#A``"/X`?^_^L%`*#A#!*?Y?PAG^4!$(_@0CV-X@(@
MD><$,(/B`!"2Y0`@D^4!$#+@=0``&D+=C>(,T(WB\(^]Z`4`H.$G_/_KU!&?
MY0$0C^``<*#A"`"@X57\_^L`D%#BY/__"KPQG^4)L*#A`S"/X!0PC>6P,9_E
ML(&?Y0,PC^`0,(WE`##;Y0B`C^```%/C/0``"@``5.,$```*"Q"@X00`H.&L
M^__K``!0XT$```H+`*#A"_S_ZP'`0.(,(-OG##"+X"\`4N,`X*#A"@``&@*0
M0.()D(O@`Y!)X`/`3.`#(*#A`*"@XPS@@^`)H,/F`1!RY2\`4>/Z__\*`3"'
MX@[@@^`!"E[CNO__JB`QG^6$H(WB`S"/X`$JH.,!$*#C!#"-Y0H`H.$(,*#A
M"%"-Y0"PC>7Z^__K!B"@X0H0H.$#`*#C*?S_ZXB0C>(``%#C`P``&F`P&>4/
M.@/B`@E3XQH```K,$)_E``"@XP$0C^`/_/_K`+"@X0``6^.=__\*`##;Y0``
M4^/!__\:``!4XQH```H`,-3E+@!3XP(```H4L)WE`>"@X]/__^H!,-3E``!3
MX_G__QI\$)_E``"@XP$0C^#Z^__K`+"@X>G__^H!$*#C"@"@X?+[_^L``%#C
MW___&E0`G^4*$*#A``"/X(S]_^L*`*#A?OO_ZX+__^H0L)WE`>"@X[O__^I\
M^__KI&L!`!0!``"L)@``?"8``#AK`0!`)@``="4``&0E```()@``A"4``"`E
M``#,)```D"0````PT.4``%/C'O\O`0$@@.(O`%/C`@"@`0$PTN0``%/C^O__
M&A[_+^$00"WI`$!0XBX```H`,-3E``!3XRL```J7^__K`3!`X@,PA.`#`%3A
M`R"@,0,``#HH``#J!`!2X0(PH.$E```*`C"@X0$04N0O`%'C^/__"@,`5.$?
M```J`3!#X@,`5.$>```*`"#3Y2\`4N/Y__\:`3!#X@,``.H`$-/E`3!#XB\`
M4>,"```:`P!4X0,@H.'X__\Z!"!"X`(P@N(!"E/C%0``BF@`G^4$$*#A``"/
MX`!`H.$!((+B`3J@XR_[_^L$`*#A$("]Z$@`G^400+WH``"/X"S[_^H#`%3A
MX___&@`PT^4O`%/C!0``"B@`G^400+WH``"/X"/[_^H``*#C$("]Z!0`G^40
M0+WH``"/X!W[_^K4:0$`I"(``#@C``!H(@``T,&?Y3!`+>D,P(_@R%&?Y<A!
MG^4,P(SB#P"\Z`50C^`TT$WB!$"5YPC@C>(`0)3E+$"-Y0!`H.,/`*[H#P"\
MZ`\`KNB8`9_E`#"<Y0``C^"P,,[AWOS_ZX@!G^6(49_E``"/X-K\_^N``9_E
M!5"/X```C^#6_/_K=`&?Y01`C>(``(_@TOS_ZV@!G^4``(_@S_S_ZV`!G^4`
M`(_@S/S_ZU@!G^4``(_@R?S_ZU`!G^4``(_@QOS_ZP4`H.'$_/_K0`&?Y0``
MC^#!_/_K.`&?Y0``C^"^_/_K,`&?Y000H.$``(_@@OS_ZP`04.(!```*!0"@
MX>?\_^L4`9_E!!"@X0``C^!Z_/_K`!!0X@(```H``9_E``"/X-[\_^OX`)_E
M!!"@X0``C^!Q_/_K`!!0XA$```KD`)_E``"/X-7\_^O<$)_EW`"?Y0$0C^``
M`(_@T/S_Z]`@G^6`,)_E`B"/X`,PDN<`()/E+#"=Y0(@,^`7```:--"-XC"`
MO>BL`)_E!!"@X0``C^!9_/_K`!!0X@,```J8`)_E``"/X+W\_^OF___JC!"?
MY0H@H.,!$(_@&0"-XBS[_^L``%#CW___&G0`G^4C$(WB``"/X+'\_^O:___J
MIOK_Z^1?``"@9P$`%`$``,`B``"X(@``\"(``+`B``"L(@``J"(``*PB```\
M(@``H"(``*0B```<(@``E"(``(@B``!`(0``>"(``*@A``"$(@``Z"$``&!F
M`0`H(@``N"$``!0B``"((0``F#"?Y9@0G^68()_E`S"/X`3@+>4!$(_@``"3
MY0(@D><,T$WB`0!PXP`@DN4$((WE`""@XPD```IL()_E9#"?Y0(@C^`#,)+G
M`""3Y00PG>4"(#/@$```&@S0C>($\)WD2`"?Y0T0H.$``(_@$/S_ZP``4.,$
M```*``#0Y3``4.,``%`3`0"@$P``H`,@,)_E`S"/X```@^7F___J9/K_Z\!F
M`0!H90$`%`$``#QE`0"H(```/&8!`!!`+>D^^O_K-_K_ZP``4.,``)`5$("]
MZ.P@G^7P0"WIZ#"?Y>A@G^4"((_@'-!-X@,PDN<&8(_@`%"@X1`0C>(&`*#A
M`#"3Y10PC>4`,*#CZ?O_ZP40H.$`0%#B`@``"@`PU.4``%/C#```&J0`G^4`
M`(_@2?S_ZYP@G^6,,)_E`B"/X`,PDN<`()/E%#"=Y0(@,^`;```:'-"-XO"`
MO>@(^O_K``!0X_+__QH%`*#A:OK_ZP!PH.$$`*#A9_K_ZP``A^`"`(#B4OK_
MZTPPG^4(0(WE`S"/X`0PC>5`,)_E`"#@XP,PC^`!$*#C`%"-Y0!`H.%H^O_K
M!!"@X08`H.$F_/_KV___ZAOZ_^N<9`$`%`$``*0@``!H(```1&0!`#`?```D
M'P``\$\MZ3C'G^4X1Y_E@=Q-XC3GG^4$T$WB#,"/X`1`C^`.X)3G`CF-X@"0
MH.$'`)SI`7R-X@#@GN7\X(/E`."@X_PP@^(00(SB=#!'X@<`@^@/`+3H7.!'
MX@\`KN@#`)3H*,",X@,`CN@'`)SH:#!'X@<`@^C4!I_EX&!'X@80H.$``(_@
MDOO_Z\0VG^4#,(_@'#"-Y0!`4.("```*`##4Y0``4^,=`0`:BO__ZP!04.+T
M```*!0"@X1[Z_^N``*#A`0"`X@GZ_^L`(-7E``!2XP"`H.$,```*>+:?Y0A`
MH.$+L(_@!`"@X0`@C>4+,*#A`"#@XP$0H.,=^O_K`2#UY0)`A.(``%+C]?__
M&D@&G^584$?B``"/X`(``.H$`)7D``!0XPT```H&$*#A:/O_ZP!`4.+X__\*
M`##4Y0``4^/U__\*O?S_ZP``4./R__\*!`"@X;OY_^L`4%#B$P``&@"@H.-T
ML$?B"B&'X'1`$N4``%3C#```"@%0BN(%48O@`"#4Y0``4N,'```*!`"@X:K\
M_^L!H(KB``!0XT,``!H$0)7D``!4X_3__QH`4*#C!0"@X=_Y_^L`0*#A"`"@
MX=SY_^L`0(3@`4N$X@1`A.($`*#AQ?G_ZX`UG^6`)9_E`S"/X`0PC>5X-9_E
M`B"/X`,PC^`!$*#C#("-Y0@@C>4`4(WE`"#@XP"`H.'8^?_K"`"@X0<=H./>
M^?_K`0!PXP,``!K/^?_K`!"0Y1$`4>.M```:!B"@X0@0H.$#`*#C"OK_ZP!0
M4.(=```*&"6?Y1P0G>4`,)GE`A"1YPPEG^4``)'E`B"/X`$0H.,`@(WEU_G_
MZP!@H./T%)_ER"2?Y0$0C^`".8WB`B"1Y_PP@^(`$)+E`""3Y0$0,N`G`0`:
M!@"@X8'<C>($T(WB\(^]Z`0`H.%C^?_K`%!0XJG__PJZ___JT#`7Y0\Z`^(!
M"5/CW?__&LBP%^4_^?_K``!;X=G__QK0,!?E@SN@X:,[H.$'#5/CU/__&@0`
MH.%[^?_K!A"@X0`PH.%H!)_E`V"@X0``C^#N^O_K``!0XXL```H`0)GE1_G_
MZP`0H.$$`*#A*_W_ZP"@4.*$```*"@"@X7SY_^L#`%#C`$"@X0P``)HD%)_E
M!`!`X@``BN`!$(_@$?G_ZP``4.,%```:!`!4X[\```H$0(K@!3!4Y2\`4^.[
M```*I?[_ZP`04.(#```:"@"@X5+Y_^L`0%#B;0``&M@3G^78`Y_E`1"/X```
MC^`P^__K6?G_Z\@SG^7((Y_E`S"/X`0PC>7`,Y_E`B"/X+RCG^6\DY_EO'.?
MY0P@C>4#,(_@`"#@XP$0H.,`@(WE"J"/X`F0C^`'<(_@"`"-Y08`H.%:^?_K
M#P``ZE7Y_^L`,)#E$0!3XQ$``!H_^?_K`5"%X@0@H.$*,*#A`1"@XPQ0C>40
MD(WE!'"-Y0"`C>4(`(WE!@"@X4GY_^L'':#C!@"@X4_Y_^L!`'#C`$"@X>G_
M_PH(`*#AX?C_ZRP#G^4&$*#A``"/X/[Z_^L&`*#AFO[_ZWO__^H%L*#A:$!'
MX@LQA^!H`!/E``!0XR0```H!@(OB"%&$X`80H.&(^O_K"+"@X0`P4.("```*
M`##3Y0``4^,$```:!`"5Y```4.,7```*`8"(XO+__^K9^/_K`%!0XNG__PKQ
M_O_J>"*?Y1P`G>4`,)GE`@"0YZ`BG^4``)#E`B"/X`00C>4`@(WE`1"@XR[Y
M_^L`8*#C5?__ZG+^_^L$`*#AQOC_ZP!@H.%0___J#0"@X^SX_^MD4I_E4R"@
MXP50C^``@*#AX?[_Z@"@F>5X___J`E"@XP`PX.,1(.#C!)!'X@!0C>73^/_K
M"1"@X08@H.,$`*#AD_C_ZP0P5^4``%/C`@``&@,P5^5#`%/C10``"@`PH.,`
M(*#C`#"-Y00`H.$`,*#CP_C_ZSP%`.L`4*#A`@``Z@D0H.$%`*#A6@4`ZP(I
MH.,)$*#A!`"@X7WX_^L`(%#B]O__R@0`H.%$0$?B'?G_ZP40H.$$`*#AE04`
MZZRAG^4PD$?B"J"/X`E0H.$!(-3D!0"@X0`@C>4*,*#A`"#@XP$0H./3^/_K
M!`!9X0)0A>+U__\:>#&?Y7@AG^4#,(_@!#"-Y7`QG^4"((_@``"@XPP@C>4(
MD(WE`("-Y0,PC^`(`$?E`"#@XP$0H.,&`*#AP/C_ZWO__^H$0)GE``!4XT#_
M_PH$`*#AJ_C_ZP,`4.,\__^:)!&?Y00`0.(``(3@`1"/X$'X_^L``%#C!*"@
M`33__^H",%?E00!3X[;__QH!,%?E0P!3X[/__QH`,-?E2`!3X[#__QH!,-?E
M10!3XZW__QH`,.#C.2#@XP0`H.$`4(WE<OC_ZPD0H.$$`*#A*2"@XS+X_^NT
M,)_EM""?Y0,PC^`$,(WEK#"?Y0(@C^`,((WE`S"/X``@X.,!$*#C!@"@X0B0
MC>4`@(WEC?C_ZTC__^I#^/_KU&0!`(!C`0`4`0``0!X``!!C`0#H'@``(!T`
M``@=``#P'0``X!T``"0!``"\'0``'&$!`&0=```@'0``!!P``(0;```H&P``
MC!T``+P<``"\'```9!T``/`:``!,&@``X!H``'P:``#(&0``L!@``!0;```T
M&@``Z!D``-P7``!`&@``;!D``.@#G^7H$Y_E``"/X/!/+>D!$)#GW#.?Y1S0
M3>+8(Y_E`S"/X``0D>44$(WE`!"@XP)0D^<08(WB``"5Y0Q@C>6=^/_K`$"@
MX0``E>6:^/_K:##4Y080H.%I,,#EG`.?Y0``C^"G^?_K``!0XP(```H`,-#E
M,0!3X[@```KD_/_K``"5Y8SX_^MT$Y_E"S"@XP$@H.,!$(_@)_C_ZP``4.--
M```*7#.?Y1`@D.4#,(_@!#"3Y1B`DN4!`%/C`)"5Y48``-I`,Y_E0+.?Y0,P
MC^`\HY_E`$"@XPNPC^`)<*#A!#"-Y0H``.H0$)'E"0"@X;KW_^L$,)WE!""3
MY0``4..:```:`D"$X@(`5.&:``"J!D"@X0<`H.%G^/_K!""@X0`PH.,($*#A
M1?C_ZP`@4.(3```*`!"2Y0@`F^4(,)'E`6"$X@HP`^`!"U/C!I&0YP!PE>7C
M__\*!P"@X0@@C>55^/_K"""=Y0(PH.,`$)+E`""@X]CW_^L`<)7E`!"@X=G_
M_^J,,I_E`)"5Y0,PC^`$,)/E`1!#X@0`4>$/```:`0!3XPT``-IL8I_E`4"@
MXP9@C^`)`*#A````Z@``E>4]^/_K"!"@X9GW_^L$,);E`4"$X@0`4^'W___*
M`)"5Y0D`H.$T^/_K,!*?Y0,PH.,!(*#C`1"/X,_W_^L`0%#B"P``"@``E>4K
M^/_K$#"4Y0PBG^4`$)/E`B"/X*CW_^L0,)3E`#"3Y0@PD^4!!1/C7@``&@``
ME>4?^/_KY!&?Y0,PH.,!(*#C`1"/X+KW_^L`0%#B"P``"LP!G^4,$)WE``"/
MX"?Y_^L`8%#B``"5Y44```H0^/_K$#"4Y08@H.$`$)/ECO?_ZP``E>4*^/_K
M`$"@X0``E>4'^/_KC!&?Y0$@H.,!$(_@N/?_ZX`AG^4"((_@`!"@X00`H.&`
M]__K``"5Y?SW_^L`,*#C#!"=Y6!1G^4%4(_@:3#`Y5@!G^4``(_@!_G_ZP``
M4.,`0*#A#`"%Y1````H'':#C!`"@X;'W_^L!,(#B$0!0XP$`4Q,M``"*)"&?
MY=0PG^4"((_@`S"2YP`@D^44,)WE`B`SX"0``!H<T(WB\(^]Z`@`E>4[_?_K
M``!0XP!`H.$,`(7EZ/__&N@`G^4``(_@E/?_ZP$PT.4``%/C1/__"D+__^H"
M,*#A!Y"@X87__^H",*#A!Y"@X09`H.&!___JRO?_Z[`PG^40()3E`S"/X`@P
MD^4``)+E`!"3Y5OZ_^NU___J``"5Y<#W_^L0,)3E`!"3Y8KW_^N:___J+O?_
MZW@@G^4`,*#A`B"/X`@0DN5L`)_E`!"1Y00@H.$``(_@</?_Z\A;`0`4`0``
ML%L!`!P!``#H%@``8!@``+!<`0"07`$`A%P!```$(`#06P$`K%L!``@7``#H
M%@``W!8``*`4``!D%@``<!8``(A:`0`4%```M%@!`-`5``#$60$`B%D!`&05
M``!P0"WI`%"@X:/[_^L`,-#E`$"@X0``4^,%```*`2"`XB\`4^,"0*`!`3#2
MY```4^/Z__\:<?S_ZP``5>,``%`3<("]"``PU>4``%/C<("]""`0G^4$`*#A
M!""@XP$0C^!Q]__K``!0XW"`O1@%`*#A<$"]Z(CY_^I@$P``Z"V?Y>@]G^4"
M((_@\$\MZ:/?3>(#,)+G#>"@X4#`@.*`8(#B#A"@X0!0H.,`,)/EA#*-Y0`P
MH.,$0!SE"'`<Y20TH.'_/`/B9R@GX"0\@^$$A*#A(B2@X00\@^$(P(SB_T@(
MXO\LPN,$,(/A9R0BX`8`7.$$4('E#%"!Y0@P@>4`(('E$!"!XNK__QI^[X[B
M"!!-X@!`H.,!P*#A2%"1Y7`PD>5T()SE3'"<Y1B`D>4(8+'E!3`CX!Q0G.4(
M,"/@!,"1Y0<@(N`&,"/@!2`BX`P@(N"CSZ#A@L",X8,PC.$.`%'AA$"!Y8`P
M@>7I__\:"'"0Y0S@D.4G$:#A#A^!X0!@D.404)#E!T^!X1@0D.7@/)_E!,"0
MY0"0G>4!@"7@INV@X2`0D.4#D)G@C.*.X0&0F>"&XH[A">">X!B0D.4$$"7@
M!X`(X`F`*.`(H)WE!A`!X":1H.$,GXGA!<`AX!@0D.4(X)[@`Z":X`:?B>$!
M$)K@$*"=Y0F`).`,$)'@[LV@X0P0D>`.@`C@`\":X&[AH.$8L)WE!(`HX`7`
MG.#AK:#A","<X`Z`*>`*P)S@`8`(X`.@F^!A$:#A(+"=Y01`FN`)@"C@[*V@
MX0B`E.`!0"[@"H"8X`Q`!.`#H)O@;,&@X2BPG>4.0"3@"9":X`20F>#HK:#A
M#$`AX`J0F>`(0`3@`Z";X&B!H.$PL)WE#N":X`%`).#IK:#A!$">X`C@+.`*
M0)3@">`.X`.@F^!ID:#A.+"=Y0$0FN`,X"[@Y*V@X0[@D>`)$"C@"N">X`00
M`>`#H)O@9$&@X4"PG>4($"'@#,":X`'`G.#NK:#A!!`IX`K`G.`.$`'@`Z";
MX&[AH.%(L)WE"1`AX`B`FN`!@)C@[*V@X0X0).`*@)C@#!`!X`.@F^!LP:#A
M4+"=Y000(>`)D)K@`9"9X.BMH.$,$"[@"I"9X`@0`>`#H)O@:(&@X5BPG>4.
M$"'@!$":X`%`E.#IK:#A"!`LX`I`E.`)$`'@`Z";X&F1H.%@L)WE#!`AX`[@
MFN`!X)[@Y*V@X0D0*.`*X)[@!!`!X`.@F^!D0:#A:+"=Y0@0(>`,P)K@`<"<
MX.ZMH.$$$"G@"L"<X`X0`>`#H)O@;N&@X7"PG>4)$"'@"(":X`&`F.#LK:#A
M#A`DX`J`F.`,$`'@`Z";X&S!H.%XL)WE!!`AX`F0FN`!D)G@Z*V@X0P0+N`*
MD)G@"!`!X`.@F^!H@:#A@+"=Y01`FN`.$"'@Z:V@X0$0E.`(0"S@"A"1X`E`
M!.`#H)O@:9&@X8BPG>4.X)K@#$`DX.&MH.$$0)[@">`HX`I`E.`!X`[@`Z";
MX&$1H.&0L)WE#,":X`C@+N`!H"G@#N"<X.3-H.$,X)[@!*`*X`/`F^`)H"K@
MF+"=Y0B`G.`*@)C@9,$AX.ZMH.$*@)C@#L`,X`,PF^`)D)/@`:`LX`J@F>#H
MS:#AL#F?Y0R@FN"@P)WE;I&@X62Q*>`#P)S@`1"<X`C`*^`,P)'@J!"=Y>KM
MH.$.X)S@:+$IX`,0D>!D0:#A!,"1X`JP*^#N3:#A"\"<X`3`G."P0)WE:A&@
MX6BA(>`#0)3@N+"=Y0Z@*N`)D)3@"I"9X.Q-H.$$D)G@;J$AX`-`F^!H@:#A
MP+"=Y0R@*N`(0)3@;,&@X>F-H.$*0)3@"$"4X&ZA+.`#@)O@":`JX,BPG>4!
M@)C@"H"8X.0=H.$!@)C@::$LX`,0F^!NX:#A!*`JX`[@D>`*X)[@9!&@X>A-
MH.$$X)[@T$"=Y6FQ(>`#0)3@#,"4X`B@*^#80)WE"J"<X.[-H.$,H)K@:+$A
MX`/`E.!ID:#A"4"<X`ZP*^!NP:#A"T"4X.KMH.$.0)3@X."=Y6B1+.`#X)[@
MZ+"=Y0J0*>`!X)[@">">X.0=H.$!X)[@:I$LX`,0F^!H@:#A\+"=Y020*>`(
M@)'@"8"8X&01H.'N3:#A!$"8X&J1(>`#@)O@#I`IX`R`F.`)@)C@Y,V@X0R`
MF.#XP)WE;K$AX&JAH.$#P)S@"""-XOB0DN4*P)S@!"`KX`(@G.!DP:#AZ$V@
MX00@DN!NH2S@`T"9X`B@*N`!0)3@"!&=Y>*=H.$*0)3@"4"4X&BA+.!NX:#A
M`Q"1X!"QG>4"H"K@#A"1X&(AH.'D[:#A"A"1X`X0D>!HH2+@`^";X`2@*N`,
MX)[@&,&=Y>&=H.$*X)[@">">X&2A(N!H@:#A`\"<X""QG>4!H"K@","<X`K`
MG.!A$:#A[JV@X0*`H.$*()S@`\";X&2A(>`.H"K@"("<X"C!G>7BG:#A"H"8
MX`F`F.!NH2'@9$&@X0/`G.`PL9WE`J`JX`3`G.!B(:#AZ$V@X0K`G.`$P)S@
M;J$BX`-`F^`(H"K@`1"4X#A!G>5H@:#A[)V@X0H0D>`)$)'@"*`BX`,PE.!N
MX:#A0+&=Y0R@*N`.X)/@;,&@X=0VG^7A3:#A"N">X`R@B.$$X)[@`:`*X`-`
MF^`,L`C@81&@X4B1G>4+L(KA`D"4X`&@C.'N+:#A"T"4X`)`E.`!L`S@#J`*
MX`,@F>`(()+@"X"*X6[AH.$"@)C@Y+V@X0X@H.$.H('A"^"8X%"!G>4"L`'@
M`X"8X`2@"N`+H(KA9$&@X5B1G>4,P)C@#,":X`2`@N'NK:#A"L"<X`2P`N`.
M@`C@`Y"9X`&0F>`+$(CA"1"1X.R-H.%NX:#A"!"1X&"!G>4.L(3A#+`+X`Z0
M!.`#@)C@;,&@X0F0B^$"()C@:+&=Y0R@CN$"()G@X8V@X0B`DN`!H`K@#"`.
MX`.PF^`"H(KA!$";X.@MH.$$0)K@81&@X0)`E.!P(9WE`;",X0BP"^`!H`S@
M`R"2X&B!H.$*H(OA>)&=Y0X@DN`"()K@"."!X>2MH.$*H)+@!.`.X`@@`>`#
MD)G@`N".X0S`F>#J+:#A#,">X&1!H.$"P)S@@"&=Y020B.$*D`G@!.`(X`,@
MDN!JH:#A#N")X0$@DN"(D9WE"A"$X0(@GN#L[:#A#B"2X`P0`>`*X`3@`Y"9
MX&S!H.$(D)G@D+&=Y0X0@>$,@(KAXNV@X0D0D>`.$)'@`H`(X`S@"N`#L)O@
M8I&@X01`F^`.((CAF+&=Y0G@C.$$()+@X4V@X00@DN`!X`[@"8`,X`-`F^!A
M$:#AH+&=Y0B`CN$*0)3@`>")X01`F.#BC:#A"$"4X`&@">`#@)O@`N`.X`R`
MF.!B(:#A"N".X:BAG>4"P('A".">X.2-H.$(X)[@`K`!X`.@FN`$P`S@9(&@
MX0F0FN`+P(SAL+&=Y0A`@N$)P)S@[IV@X0G`G.`(H`+@`Y";X`Y`!.`*0(3A
M;N&@X;BAG>4!$)G@`1"4X`Z0B.'L3:#A!!"1X`R0">`.L`C@`Z":X&Q!H.$+
ML(GA`B":X,"AG>4$D([AX<V@X0(@F^`,()+@!+`.X`.@FN`!D`G@8<&@X0N0
MB>$(@)K@R+&=Y0P0A.$(@)G@XIV@X0F`F.`,H`3@`Y";X`(0`>#0L9WE8B&@
MX0[@F>`*$('A#A"1X`*@C.'H[:#A#A"1X`B@"N`"D`S@`^";X&B!H.$)D(KA
M!.">X-BAG>4(0(+A#N"9X.&=H.$)X)[@`4`$X`B0`N`#,)K@"4"$X>"QG>4,
MP)/@9#.?Y>Z=H.$,P)3@"<"<X&%!*.`#L)O@`K";X`Y`).#H(9WE;N&@X>R=
MH.$$0)O@"4"4X&&1+N`#()+@#)`IX`@@DN#P@9WE"2"2X.2=H.$)H)+@81&@
MX6PA+N`#@)C@`1"8X`2`(N#X(9WE9$&@X0@0D>#JC:#A"!"1X&R!).`#()+@
M"H`HX`X@DN``XIWE"""2X.&-H.$(L)+@;,&@X6HA).`#X)[@#,">X`'@(N`(
M(IWE81&@X0[`G.#K[:#A#N"<X&J!(>`#P)+@"X`HX`3`G.`00IWE","<X.Z-
MH.$(P)S@:B&@X6N!(>`#0)3@#H`HX`)`E.`8(IWE;N&@X>R=H.$(0)3@"4"4
MX&N!+N`#()+@#(`HX`$@DN`@$IWE"""2X.2=H.$)H)+@:X&@X6PA+N`#$)'@
M"!"1X`2`(N`H(IWE9$&@X0@0D>#JC:#A"!"1X&R!).`#()+@"H`HX`X@DN`P
MXIWE"""2X.&=H.$)L)+@;,&@X6HA).`#X)[@#,">X`'@(N`X(IWE81&@X0[`
MG.#K[:#A#L"<X&KA(>`#()+@!$"2X`L@+N!`XIWE`B"4X.Q-H.$$0)+@:I&@
MX6LA(>`#X)[@"9">X`S@(N!((IWE;,&@X0Z0F>#D[:#A#N"9X&N!+.`#()+@
M`1"2X`0@*.!0@IWE[JV@X0(0D>`*$)'@9)$LX&LAH.$#@)C@#I`IX`*`F.!8
M(IWEX:V@X0F`F.!ND:#A"H"8X&3A*>`#()+@`>`NX`P@DN!@PIWE#B"2X.CM
MH.$.()+@9$&@X6'A*>`#P)S@".`NX`1`G.!HPIWE:(&@X>*MH.$.0)3@"D"4
MX`G@H.%AH2C@`Y"<X`*@*N!PPIWE#I"9X`J0F>!BX:#AY"V@X0*0F>!A$:#A
M`R"<X`Z@*.`!()+@!*`JX'@2G>4*()+@Z<V@X0S`DN!D0:#A`S"1X`0@+N`&
M,)/@"2`BX`@PD^`",)/@["V@X0(PD^`8()#E:9&@X0?`G.`%D)G@`D"4X"`@
MD.4`,(#E`N">X&0@G^5,,)_E`!"@XP(@C^`(P(#E$)"`Y1A`@.4@X(#E!!"`
MY0P0@.44$(#E'!"`Y200@.4#,)+G`""3Y80RG>4"(#/@`0``&J/?C>+PC[WH
M<?/_Z_A6`0`4`0``F7F"6J'KV6[<O!N/UL%BREA)`0#P02WI@`"@XX[S_^M0
M4(_BT$#%X5!PC^+08,?A`""@X_!`P.%(4(_BT$#%X?A@P.'P0<#A0%"/XM!`
MQ>%`<(_BT&#'X?!"P.$`0*#C`%"@X_AAP.%X((#E^$+`X?!#P.'P@;WH`2-%
M9P````")J\WO`````/[<NI@`````\.'2PP````!V5#(0`````/A/+>D"8*#A
MV"+`X0!0H.$`D*#CA@&@X0*`@.`)`%/A"`!2`0%`H.$P()7E-!"5Y0:@H.'&
MOZ#A`0``F@$@DN()$*'@JCZ@X7@`E>6+,8/A`C"3X*LNH.$!(*+@``!0X_B"
MQ>$P,(7E.("%XC0@A>46```:/P!6XR4``-I`8$;B)I.@X0%PB>('<X3@0""@
MXP00H.$(`*#A`D"$X`WS_^L%`*#A+_S_ZP<`5.'V__\:"9UIX`ECAN`'$*#A
M"`"@X08@H.$#\__K>&"%Y?B/O>A`<&#B!P!6X09PH+$``(C@!R"@X000H.'Z
M\O_K>#"5Y0,PA^!``%/C>#"%Y?B/O1@%`*#A!V!&X`=`A.`5_/_KU___Z@1P
MH.'F___J\$$MZ2A@D>4P<)'E`4"@X:8AH.$_(`+B9C@FX&<8)^`X@(3B?\#@
MXR,TH.$A%*#A`L#(YP$@@N+_/,/C_QS!XS@`4N,`4*#A9F0CX`(`B.!G="'@
M/```VD`@8N(`$*#C._/_ZP0`H.'W^__K"`"@X3@@H.,`$*#C-?/_ZP0`H.%P
M<(3E=&"$Y>_[_^L#,-3E`##%Y;(PU.$!,,7E`#"4Y00`H.$C-*#A`C#%Y0`P
ME.4#,,7E"S#4Y00PQ>6Z,-3A!3#%Y0@PE.4C-*#A!C#%Y0@PE.4',,7E$S#4
MY0@PQ>6R,=3A"3#%Y1`PE.4C-*#A"C#%Y1`PE.4+,,7E&S#4Y0PPQ>6Z,=3A
M#3#%Y1@PE.4C-*#A#C#%Y1@PE.4/,,7E(S#4Y1`PQ>6R,M3A$3#%Y2`PE.4C
M-*#A$C#%Y2`PE.43,,7E\$&]Z)7R_^HX(&+B`!"@X_[R_^O'___J\$<MZ4Q@
MG^5,4)_E!F"/X`50C^`%8$;@`'"@X0&`H.$"D*#A:O+_ZT9AL.'PA[T(`$"@
MXP0PE>0!0(3B"2"@X0@0H.$'`*#A,_\OX00`5N'W__\:\(>]Z-!$`0#(1`$`
M'O\OX0@PG^4#,(_@`#"3Y8_R_^K41@$`"$`MZ0B`O>@!``(`+W1M<``````N
M````4$%27U1-4$1)4@``5$5-4$1)4@!435``55-%4@````!54T523D%-10``
M```N+@``)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O
M=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I
M+R5S`&5X90!005)?5$5-4`````!005)?4%)/1TY!344`````.@```"5S)7,E
M<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/
M``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````4$%2
M7T1%0E5'````4$%27T-!0TA%````4$%27T=,3T)!3%]$14)51P````!005)?
M1TQ/0D%,7U1-4$1)4@```%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`````%!!4E]#3$5!3CT``#$```!,1%],24)205)97U!!5$@`4UE35$5-
M```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E
M(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%42```
M``!P87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U
M)7,````E<R5S=&5M<"TE=2TE=25S`````$%21U8`````&````'!E<FP`````
M4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-3````!5;F%B;&4@=&\@8W)E
M871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M`"UE```M+0``979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP
M86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A<E]T96UP+"`D
M<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P*
M*3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT
M(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R
M7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K
M(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D
M(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M
M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH
M)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@
M<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"
M14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT
M97)N86QS.CI005(Z.D)/3U0["B1005)?34%'24,@/2`B7&Y005(N<&U<;B([
M"F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@
M/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/
M(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?
M9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G
M+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@
M*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?
M7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T
M.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N
M86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&UA9VEC7W!O
M<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2!["B1M86=I8U]P;W,@/2`P
M.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C:'5N:U]S:7IE*2`^(#`I
M('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@96QS92!["B1M86=I8U]P
M;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H:6QE("@D;6%G:6-?<&]S
M(#X](#`I('L*<V5E:RA?1D@L("1M86=I8U]P;W,L(#`I.PIR96%D*%]&2"P@
M)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RDI.PII9B`H
M*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1M
M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?
M<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P.PIS965K(%]&2"P@)&UA
M9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?
M<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D
M8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@
M9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE
M("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA
M;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]
M("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B
M+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*
M96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y
M.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C
M(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D
M8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D
M=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4[
M"FUY("1I;F9O(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@;W(@
M<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L
M92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE
M.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D
M:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1I;F9O+3Y[8G5F?3L*
M<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL
M96YA;64@/2!?=&5M<&9I;&4H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[
M8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A
M;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN
M9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@
M(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U
M;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!
M4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET
M>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT[
M"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO
M;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?
M=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@
M<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'
M5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%0
M4%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R
M;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD
M05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T
M.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@
M97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B
M=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE
M(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]
M"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R
M(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@
M97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII
M9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!
M4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.
M0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z
M.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@
M(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S
M*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R
M.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O
M7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B
M)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!0
M05(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A
M=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*
M24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@
M24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O
M<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA
M<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@
M/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R
M+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM
M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L
M(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B
M("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME
M>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I
M8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI
M*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@
M*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE
M<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U
M;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E
M;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F
M:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0[
M"GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A
M9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F
M:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE
M>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M
M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D
M;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*
M;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@
M9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C
M;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II
M9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI
M>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P
M;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E
M;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS
M<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD
M>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N
M86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?
M;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F:"P@(CPB+"`D
M;W5T*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M*"1F:"D["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H
M95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD
M8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^8VQO<V4[
M"F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I
M;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005([
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I
M;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/
M.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R
M8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O
M<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV
M93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A
M.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D[
M"G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO
M=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T
M(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE
M;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M
M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D
M;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF
M:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E
M<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL
M("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]
M("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P
M:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T
M("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@
M(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X
M=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E
M<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@
M0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-
M;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM
M8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E
M4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA
M;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z
M.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P
M871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?
M;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E
M<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN
M9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!
M4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@
M<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![
M(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI
M=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z
M.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I
M<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]
M"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@
M/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[
M)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I
M*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I
M;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R
M;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^
M*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN
M3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L
M<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*
M96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%
M4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D
M<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B
M2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D
M14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M
M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K
M("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B
M=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@
M)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1D
M:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]
M($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH;7D@)&9H+"`B/"(L("1P<F]G
M;F%M92D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S
M92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@?'P@)&UT:6UE.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&1I9V5S="(["GT*8VQO<V4H
M)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!]
M(#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P
M87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@
M)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?
M=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP
M;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M
M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN
M;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM
M;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H
M)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]
M"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.
M04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE
M('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA
M;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T
M<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM
M?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M
M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*
M:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@
M+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER
M("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@
M>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D
M14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D
M+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?
M<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@
M,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E
M=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'
M971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S
M+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D
M96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B
M(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK
M(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@
M0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!
M4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A
M97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@
M<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.
M5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<
M4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L
M;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B
M0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S
M:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]
M+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L
M:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E
M(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD
M7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@
M0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F
M:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D
M<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`
M(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%
M4E)/4CL*,3L*7U]%3D1?7PH`````<&5R;'AS:2YC````7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("``````5)'_?P$`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````.09``!\&0```0````$`
M```!````RP$```$````:`@```0```&8#```,````E!(```T````X20``&0``
M`*"-`0`;````!````!H```"DC0$`'`````0```#U_O]OK`$```4```!\"0``
M!@```)P"```*````^@0```L````0````%0`````````#````N(X!``(```#X
M`0``%````!$````7````G!```!$```"T#P``$@```.@````3````"````!X`
M```(````^___;P$```C^__]O5`\``/___V\#````\/__;W8.``#Z__]O$```
M``````````````````````````````````````````````````````"HC0$`
M``````````"@$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2``"@
M$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2
M``"@$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(`
M`*`2``"@$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2``"@$@``
MH!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2``"@
M$@``H!(``*`2``"@$@``H!(``*`2``"@$@``H!(``*`2```@20``````````
M````````````````````````````````````````P$@```````"H%0``````
M``````````````````20`0#_____1$D``$Q)````````4$D``%1)``!<20``
MX$D``&1)````````:$D``'!)````````@$P``$=#0SH@*$1E8FEA;B`Y+C,N
M,"TS*2`Y+C,N,`!!*@```&%E86)I``$@````!35410`&!`@!"0$2!!,!%`$5
M`1<#&`$9`1H"`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI
M9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI
M;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED>``N96A?9G)A;64`
M+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N
M8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````````````````
M````````````````````````````````"P````$````"````5`$``%0!```3
M```````````````!`````````!,````'`````@```&@!``!H`0``)```````
M````````!``````````F````!P````(```",`0``C`$``"``````````````
M``0`````````-````/;__V\"````K`$``*P!``#P````!0`````````$````
M!````#X````+`````@```)P"``"<`@``X`8```8````#````!````!````!&
M`````P````(```!\"0``?`D``/H$``````````````$`````````3@```/__
M_V\"````=@X``'8.``#<````!0`````````"`````@```%L```#^__]O`@``
M`%0/``!4#P``8`````8````#````!`````````!J````"0````(```"T#P``
MM`\``.@````%``````````0````(````<P````D```!"````G!```)P0``#X
M`0``!0```!4````$````"````'P````!````!@```)02``"4$@``#```````
M````````!`````````!W`````0````8```"@$@``H!(```@#````````````
M``0````$````@@````$````&````J!4``*@5``"0,P`````````````(````
M`````(@````!````!@```#A)```X20``"```````````````!`````````".
M`````0````(```!`20``0$D``-8]``````````````0`````````E@````$`
M`'""````&(<``!B'```(````#0`````````$`````````*$````!`````@``
M`""'```@AP``!```````````````!`````````"K````#@````,```"@C0$`
MH(T```0```````````````0````$````MP````\````#````I(T!`*2-```$
M```````````````$````!````,,````&`````P```*B-`0"HC0``$`$```8`
M````````!`````@```#,`````0````,```"XC@$`N(X``$@!````````````
M``0````$````T0````$````#`````)`!``"0``!````````````````$````
M`````-<````(`````P```$"0`0!`D```&!``````````````!`````````#<
M`````0```#``````````0)```!P```````````````$````!````Y0````,`
M`'```````````%R0```K```````````````!``````````$````#````````
=``````"'D```]0```````````````0``````````
